@@ -23,12 +23,9 @@ using Gtk;
 using Mono.Unix;
 using System.Collections;
 
-public class CustomGameDialog
+public class CustomGameDialog : GtkDialog
 {
 	static ListStore games_store;
-	private Glade.XML xml;
-	private Gtk.Dialog dialog;
-	private const string dialog_name = "customgame";
 	[Glade.Widget] Gtk.TreeView treeview;
 	[Glade.Widget] Box preview_vbox;
 	[Glade.Widget] Label preview_question;
@@ -37,8 +34,7 @@ public class CustomGameDialog
 	int ngames, npos;
 	Type [] custom_games;
 
-
-	public CustomGameDialog (GameManager manager)
+	public CustomGameDialog (GameManager manager) : base ("customgame")
 	{
 		Game game;
 		Type[] games;
@@ -48,10 +44,8 @@ public class CustomGameDialog
 		this.manager = manager;
 		gm = new GameManager ();
 		gm.GameType = GameSession.Types.AllGames;
-		games = gm.Games;
+		games = gm.CustomGames;
 		dialog = null;
-		xml = new Glade.XML (null, "gbrainy.glade", dialog_name, "gbrainy");
-		xml.Autoconnect (this);
 
 		drawing_area = new CairoPreview ();
 		preview_vbox.Add (drawing_area);
@@ -107,7 +101,6 @@ public class CustomGameDialog
 		}
 
 		treeview.Model = games_store;
-		Dialog.IconName = "gbrainy";
 		game =  (Game) Activator.CreateInstance (games [0], true);
 		game.Initialize ();
 		drawing_area.puzzle = game;
@@ -115,20 +108,6 @@ public class CustomGameDialog
 		treeview.ColumnsAutosize ();
 	}
 
-	public int Run ()
-	{
-		return Dialog.Run ();
-	}
-
-	public Gtk.Dialog Dialog {
-		get {
-			if (dialog == null)
-				dialog = (Gtk.Dialog) xml.GetWidget (dialog_name);
-				
-			return dialog;
-		}
-	}
-
 	public int NumOfGames {
 		get { return ngames;}
 	}
@@ -203,7 +182,7 @@ public class CustomGameDialog
 		});
 
 		
-		manager.Games = custom_games;
+		manager.CustomGames = custom_games;
 	}
 
 	public class CairoPreview : DrawingArea 
@@ -215,12 +194,24 @@ public class CustomGameDialog
 			if(!IsRealized)
 				return false;
 
-			int w, h;
+			int w, h, nw, nh;
+			double x = 0, y = 0;
 			Cairo.Context cc = Gdk.CairoHelper.Create (args.Window);
 			CairoContextEx cr = new CairoContextEx (cc.Handle);   
 			args.Window.GetSize (out w, out h);
-			puzzle.DrawPreview (cr, w, h);
 
+			nh = nw = Math.Min (w, h);
+
+			if (nw < w) {
+				x = (w - nw) / 2;
+			}
+
+			if (nh < h) {
+				y = (h - nh) / 2;
+			}
+
+			cr.Translate (x, y);
+			puzzle.DrawPreview (cr, nw, nh);
 			((IDisposable)cc).Dispose();
 			((IDisposable)cr).Dispose();
    			return base.OnExposeEvent(args);
