@@ -240,23 +240,29 @@ abstract public class Game
 	{
 		return (String.Compare (answer, right_answer, true) == 0);
 	}
+
+	// When asking for a list of figures people trends to use spaces or commas
+	// to separate the elements
+	static public string TrimAnswer (string answer)
+	{
+		string rslt = string.Empty;
+
+		for (int i = 0; i < answer.Length; i++)
+		{
+			if (answer[i]==' ' || answer[i] == ',')
+				continue;
+
+			rslt += answer[i];
+		}
+		return rslt;
+	}
 	
-	public void SetLargeFont (CairoContextEx gr)
-	{
-		gr.SetFontSize (0.05);
-	}
-
-	public void SetNormalFont (CairoContextEx gr)
-	{
-		gr.SetFontSize (0.03);
-	}
-
 	virtual public void PrepareGC (CairoContextEx gr)
 	{
 		gr.LineWidth = LineWidth;
 		gr.Color = DefaultDrawingColor;
 		gr.SelectFontFace ("Sans", FontSlant.Normal, FontWeight.Bold);
-		SetNormalFont (gr);
+		gr.SetNormalFont ();
 	}
 
 	protected void DrawBackground (CairoContextEx gr)
