@@ -90,12 +90,15 @@ public class GameDrawingArea : DrawingArea
 		gr.Scale (area_width, area_height);
 		DrawBackground (gr);
 		gr.Color = new Cairo.Color (0, 0, 0, 1);
+		gr.Save ();
 		gr.SetFontSize (0.035);
+		gr.SelectFontFace ("Sans", FontSlant.Normal, FontWeight.Bold);
 
 		gr.MoveTo (0.05, y);
 		gr.ShowText (String.Format (Catalog.GetString ("Welcome to gbrainy {0}"), Defines.VERSION));
 		gr.Stroke ();
 
+		gr.Restore ();
 		gr.SetFontSize (0.03);
 		gr.DrawStringWithWrapping (0.05, y + 0.08, line_space, Catalog.GetString ("gbrainy is a brain teaser game and trainer to have fun and to keep your brain trained. It includes:"));
 
@@ -109,7 +112,7 @@ public class GameDrawingArea : DrawingArea
 			gr.Paint ();
 			gr.Restore ();
 		}
-		gr.DrawStringWithWrapping (0.21, y + 0.03, line_space, Catalog.GetString ("Logic puzzles. Designed to challenge your reasoning and thinking skills."));
+		gr.DrawStringWithWrapping (0.23, y + 0.03, line_space, Catalog.GetString ("Logic puzzles. Designed to challenge your reasoning and thinking skills."));
 
 		y += space;
 		image = new ImageSurface (Defines.DATA_DIR + "math-games-80.png");
@@ -121,7 +124,7 @@ public class GameDrawingArea : DrawingArea
 			gr.Paint ();
 			gr.Restore ();
 		}
-		gr.DrawStringWithWrapping (0.21, y + 0.03, line_space, Catalog.GetString ("Mental calculation. Based on arithmetical operations that test your mental calculation abilities."));
+		gr.DrawStringWithWrapping (0.23, y + 0.03, line_space, Catalog.GetString ("Mental calculation. Based on arithmetical operations that test your mental calculation abilities."));
 
 		y += space;
 		image = new ImageSurface (Defines.DATA_DIR + "memory-games-80.png");
@@ -133,7 +136,7 @@ public class GameDrawingArea : DrawingArea
 			gr.Paint ();
 			gr.Restore ();
 		}
-		gr.DrawStringWithWrapping (0.21, y + 0.03, line_space, Catalog.GetString ("Memory trainers. To prove and enhance your short term memory."));
+		gr.DrawStringWithWrapping (0.23, y + 0.03, line_space, Catalog.GetString ("Memory trainers. To prove and enhance your short term memory."));
 		gr.Stroke ();
 
 		gr.DrawStringWithWrapping (0.05, y + 0.23, line_space, Catalog.GetString ("Use the Settings to adjust the difficulty level of the game."));
@@ -144,8 +147,7 @@ public class GameDrawingArea : DrawingArea
 	{
 		lock (this) {
 			if (countdown_time == 1) {
-				timer.Enabled = false;
-				timer.Dispose ();
+				EndDrawCountDown ();
 				Application.Invoke ( delegate { 
 					finish (this, EventArgs.Empty);
 				});
@@ -155,6 +157,16 @@ public class GameDrawingArea : DrawingArea
 		}
 	}
 
+	public void EndDrawCountDown ()
+	{
+		if (timer == null)
+			return;
+
+		timer.Enabled = false;
+		timer.Dispose ();
+		timer = null;
+	}
+
 	public void OnDrawCountDown (EventHandler OnFinish)
 	{
 		mode = Modes.CountDown;
@@ -163,7 +175,7 @@ public class GameDrawingArea : DrawingArea
 		countdown_time = 3;
 		timer = new System.Timers.Timer ();
 		timer.Elapsed += TimerUpdater;
-		timer.Interval = (1 * 1000); // 1 seconds
+		timer.Interval = (1 * 1000); // 1 second
 		timer.Enabled = true;
 		finish = OnFinish;
 	}
@@ -194,11 +206,62 @@ public class GameDrawingArea : DrawingArea
 
 	}
 
+	public void DrawBar (CairoContextEx gr, double x, double y, double w, double h, double percentage)
+	{
+		double per = percentage / 100;
+	
+		gr.Rectangle (x, y - h * per, w, h * per);
+		gr.FillGradient (x, y - h * per, w, h * per, new Cairo.Color (0, 0, 1));
+		gr.MoveTo (x, (y - 0.02) - h * per);
+		gr.ShowText (String.Format ("{0}%", percentage));
+		gr.Stroke ();
+
+		gr.Save ();
+		gr.Color = new Cairo.Color (0, 0, 0);	
+		gr.MoveTo (x, y);
+		gr.LineTo (x, y - h * per);
+		gr.LineTo (x + w, y - h * per);
+		gr.LineTo (x + w, y);
+		gr.LineTo (x, y);
+		gr.Stroke ();
+		gr.Restore ();
+	}
+
+	private void DrawGraphicBar (CairoContextEx gr, double x, double y)
+	{
+		double area_w = 0.8, area_h = 0.28;
+		double bar_w = 0.05, bar_h = area_h - 0.02;
+		
+		gr.LineWidth = 0.005;
+
+		// Axis
+		gr.MoveTo (x, y);
+		gr.LineTo (x, y + area_h);
+		gr.LineTo (x + area_w, y + area_h);
+		gr.Stroke ();
+
+		x = x + 0.1;
+		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.TotalScore);
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Total"));
+
+		x = x + 0.2;
+		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.LogicScore);
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Logic")); 
+
+		x = x + 0.2;
+		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.MathScore);
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Calculation"));
+
+		x = x + 0.2;
+		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.MemoryScore);
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Memory"));
+	}
+
 	private void DrawScores (CairoContextEx gr, int area_width, int area_height)
 	{
 		double y = 0.08, x = 0.05;
 		double space_small = 0.06;
-		string str;
+		string s;
 
 		gr.Scale (area_width, area_height);
 		gr.Color = new Cairo.Color (1, 1, 1);
@@ -207,58 +270,41 @@ public class GameDrawingArea : DrawingArea
 
 		gr.SetFontSize (0.03);
 		gr.MoveTo (x, y);
-		gr.ShowText (Catalog.GetString ("Score"));		
+		gr.ShowText (Catalog.GetString ("Score"));
 		DrawBand (gr, 0.03, y - 0.04);
 
 		gr.SetFontSize (0.03);
 		y += 0.08;
 		gr.MoveTo (x, y);
-		gr.ShowText (String.Format (Catalog.GetString ("Your total score is {0}%"), session.TotalScore));
 
-		y += space_small;	
-		gr.MoveTo (x, y);
-
-		if (session.LogicGamesPlayed == 0)
-			str = Catalog.GetString ("No logic puzzle games played");
-		else
-			str = String.Format (Catalog.GetString ("Logic puzzle score is {0}%"), session.LogicScore);
-
-		gr.ShowText (str);
-
-		y += space_small;
-		gr.MoveTo (x, y);
-
-		if (session.MathGamesPlayed == 0)
-			str = Catalog.GetString ("No mental calculation games played");
-		else
-			str = String.Format (Catalog.GetString ("Mental calculation score is {0}%"), session.MathScore);
-
-		gr.ShowText (str);
-
-		y += space_small;
-		gr.MoveTo (x, y);
-
-		if (session.MemoryGamesPlayed == 0)
-			str = Catalog.GetString ("No memory games played");
-		else
-			str = String.Format (Catalog.GetString ("Memory score is {0}%"),  session.MemoryScore);
-
-		gr.ShowText (str);
-
-		y += 0.08;
-		gr.SetFontSize (0.03);
-		gr.MoveTo (x, y);
-		gr.ShowText (Catalog.GetString ("Game statistics"));
-		DrawBand (gr, 0.03, y - 0.04);
+		if (session.GamesPlayed >= 10) {
+			if (session.TotalScore >= 90)
+				s = String.Format (Catalog.GetString ("Outstanding results"));
+			else if (session.TotalScore >= 80) 
+				s = String.Format (Catalog.GetString ("Excellent results"));
+			else if (session.TotalScore >= 50) 
+				s = String.Format (Catalog.GetString ("Good results"));
+			else if (session.TotalScore >= 30) 
+				s = String.Format (Catalog.GetString ("Poor results"));
+			else s = String.Format (Catalog.GetString ("Disappointing results"));
+		} else 
+			s = String.Empty;
 
 		gr.SetFontSize (0.03);
-		y += 0.08;
 		gr.MoveTo (x, y);
-		gr.ShowText (String.Format (Catalog.GetString ("Total games won: {0} ({1} played)"), session.GamesWon, session.GamesPlayed));	
+
+		if (s == String.Empty)
+			gr.ShowText (String.Format (Catalog.GetString ("Games won: {0} ({1} played)"), session.GamesWon, session.GamesPlayed));	
+		else 
+			gr.ShowText (String.Format (Catalog.GetString ("{0}. Games won: {1} ({2} played)"), s, session.GamesWon, session.GamesPlayed));	
+
 		y += space_small;
 		gr.MoveTo (x, y);
-		gr.ShowText (String.Format (Catalog.GetString ("Total time played {0} (average per game {1})"), session.GameTime, session.TimePerGame));
-		y += 0.08;
+		gr.ShowText (String.Format (Catalog.GetString ("Time played {0} (average per game {1})"), session.GameTime, session.TimePerGame));
+		
+		y += 0.06;
+		DrawGraphicBar (gr, x + 0.05, y);
+		y += 0.42;
 
 		gr.SetFontSize (0.03);
 		gr.MoveTo (x, y);
@@ -269,7 +315,7 @@ public class GameDrawingArea : DrawingArea
 		y += 0.08;
 		for (int i = 0; i < tips_shown; i++)
 		{
-			y = gr.DrawStringWithWrapping (x, y, space_small, "- " + GetTip ((int) random_indices[i]));
+			y = gr.DrawStringWithWrapping (x, y, space_small, "- " + GetTip (random_indices[i]));
 			if (y > 0.85)
 				break;
 
@@ -277,7 +323,6 @@ public class GameDrawingArea : DrawingArea
 		}
 	
 		gr.Stroke ();
-
 	}
 
 	private String GetTip (int tip)
@@ -313,23 +358,37 @@ public class GameDrawingArea : DrawingArea
 		if(!IsRealized)
 			return false;
 
-		int w, h;
+		int w, h, nw, nh;
+		double x = 0, y = 0;
 		args.Window.GetSize (out w, out h);
 		Cairo.Context cc = Gdk.CairoHelper.Create (args.Window);
 		CairoContextEx cr = new CairoContextEx (cc.Handle);
 
+		// We want a square drawing area for the puzzles then the figures are shown as designed. 
+		// For example, squares are squares. This also makes sure that proportions are kept when resizing
+		nh = nw = Math.Min (w, h);
+
+		if (nw < w) {
+			x = (w - nw) / 2;
+		}
+
+		if (nh < h) {
+			y = (h - nh) / 2;
+		}
+
+		cr.Translate (x, y);
 		switch (mode) {
 		case Modes.Welcome:
-			DrawWelcome (cr, w, h);
+			DrawWelcome (cr, nw, nh);
 			break;
 		case Modes.Scores:
-			DrawScores (cr, w, h);
+			DrawScores (cr, nw, nh);
 			break;	
 		case Modes.Puzzle:
-			puzzle.Draw (cr, w, h);
+			puzzle.Draw (cr, nw, nh);
 			break;
 		case Modes.CountDown:
-			DrawCountDown (cr, w, h);
+			DrawCountDown (cr, nw, nh);
 			break;
 		}
 
