@@ -26,12 +26,12 @@ public class PuzzleDivideCircle : Game
 	private const double figure_size = 0.15;
 	private int dots;
 	
-	private class Cercle
+	private class Circle
 	{	
 		public double x;
 		public double y;
 
-		public Cercle (double x, double y) 
+		public Circle (double x, double y) 
 		{
 			this.x = x;
 			this.y = y;
@@ -63,11 +63,11 @@ public class PuzzleDivideCircle : Game
 		}			
 	}
 
-	private void DrawAndConnectPoints (CairoContextEx gr, double x, double y, Cercle[] cercles, bool connect)
+	private void DrawAndConnectPoints (CairoContextEx gr, double x, double y, Circle[] circles, bool connect)
 	{
 		double point_size = 0.01;
-		for (int i = 0; i < cercles.Length; i++) {
-			gr.Arc (x + point_size + cercles[i].x, y + point_size + cercles[i].y, point_size, 0, 2 * Math.PI);
+		for (int i = 0; i < circles.Length; i++) {
+			gr.Arc (x + point_size + circles[i].x, y + point_size + circles[i].y, point_size, 0, 2 * Math.PI);
 			gr.Fill ();
 			gr.Stroke ();
 		}
@@ -78,10 +78,10 @@ public class PuzzleDivideCircle : Game
 		gr.Save ();
 		gr.LineWidth = 0.003;
 		double offset = point_size;
-		for (int from = 0; from < cercles.Length; from++) {
-			for (int to = 0; to < cercles.Length; to++) {
-				gr.MoveTo (x + cercles[from].x+ offset, y + cercles[from].y + offset);
-				gr.LineTo (x + cercles[to].x + offset, y + cercles[to].y + offset);
+		for (int from = 0; from < circles.Length; from++) {
+			for (int to = 0; to < circles.Length; to++) {
+				gr.MoveTo (x + circles[from].x+ offset, y + circles[from].y + offset);
+				gr.LineTo (x + circles[to].x + offset, y + circles[to].y + offset);
 				gr.Stroke ();
 			}
 		}
@@ -93,52 +93,52 @@ public class PuzzleDivideCircle : Game
 		double x = DrawAreaX + 0.05, y = DrawAreaY;
 		double pos_x = x;
 		double pos_y = y;
-		Cercle[] cercles = null;
+		Circle[] circles = null;
 
 		gr.Scale (area_width, area_height);
 
 		DrawBackground (gr);
 		PrepareGC (gr);
 
-		// First cercle
+		// First circle
 		gr.Arc (pos_x + figure_size, y + figure_size, figure_size, 0, 2 * Math.PI);
 		gr.Stroke ();
 		DrawAndConnectPoints (gr, pos_x, pos_y, 
-			new Cercle [] {
-				new Cercle (0.14, 0),
-				new Cercle (0.14, 0.29),
+			new Circle [] {
+				new Circle (0.14, 0),
+				new Circle (0.14, 0.29),
 			}, true);
 
 		gr.MoveTo (pos_x, pos_y + figure_size * 2 + 0.05);
 		gr.ShowText (String.Format (Catalog.GetString ("Has {0} regions"), 2));
 		gr.Stroke ();
 
-		// Second cercle
+		// Second circle
 		pos_x += 0.4;
 		gr.Arc (pos_x + figure_size, pos_y + figure_size, figure_size, 0, 2 * Math.PI);
 		gr.Stroke ();		
 		DrawAndConnectPoints (gr, pos_x, pos_y,
-			new Cercle [] {
-				new Cercle (0.01, 0.06),
-				new Cercle (0.27, 0.06),
-				new Cercle (0.14, 0.29),
+			new Circle [] {
+				new Circle (0.01, 0.06),
+				new Circle (0.27, 0.06),
+				new Circle (0.14, 0.29),
 			}, true);
 
 		gr.MoveTo (pos_x, pos_y + figure_size * 2 + 0.05);
 		gr.ShowText (String.Format (Catalog.GetString ("Has {0} regions"), 4));
 		gr.Stroke ();
 
-		// Third cercle
+		// Third circle
 		pos_x = x;
 		pos_y += 0.45;
 		gr.Arc (pos_x + figure_size, pos_y + figure_size, figure_size, 0, 2 * Math.PI);
 		gr.Stroke ();		
 		DrawAndConnectPoints (gr, pos_x, pos_y,
-			new Cercle [] {
-				new Cercle (0.01, 0.06),
-				new Cercle (0.27, 0.06),
-				new Cercle (0.01, 0.21),
-				new Cercle (0.27, 0.21),
+			new Circle [] {
+				new Circle (0.01, 0.06),
+				new Circle (0.27, 0.06),
+				new Circle (0.01, 0.21),
+				new Circle (0.27, 0.21),
 			}, true);
 
 		gr.MoveTo (pos_x, pos_y + figure_size * 2 + 0.05);
@@ -147,31 +147,31 @@ public class PuzzleDivideCircle : Game
 
 		switch (dots) {
 		case 5:
-			cercles =  new Cercle [] {
-				new Cercle (0.01, 0.06),
-				new Cercle (0.27, 0.06),
-				new Cercle (0.01, 0.21),
-				new Cercle (0.27, 0.21),
-				new Cercle (0.14, 0),
+			circles =  new Circle [] {
+				new Circle (0.01, 0.06),
+				new Circle (0.27, 0.06),
+				new Circle (0.01, 0.21),
+				new Circle (0.27, 0.21),
+				new Circle (0.14, 0),
 			};
 			break;
 		case 6:
-			cercles =  new Cercle [] {
-				new Cercle (0.01, 0.06),
-				new Cercle (0.27, 0.06),
-				new Cercle (0.01, 0.21),
-				new Cercle (0.27, 0.21),
-				new Cercle (0.14, 0),
-				new Cercle (0.14, 0.29)
+			circles =  new Circle [] {
+				new Circle (0.01, 0.06),
+				new Circle (0.27, 0.06),
+				new Circle (0.01, 0.21),
+				new Circle (0.27, 0.21),
+				new Circle (0.14, 0),
+				new Circle (0.14, 0.29)
 			};
 			break;
 		}
 
-		// Forth cercle
+		// Forth circle
 		pos_x += 0.4;
 		gr.Arc (pos_x + figure_size, pos_y + figure_size, figure_size, 0, 2 * Math.PI);
 		gr.Stroke ();		
-		DrawAndConnectPoints (gr, pos_x, pos_y, cercles, DrawAnswer);
+		DrawAndConnectPoints (gr, pos_x, pos_y, circles, DrawAnswer);
 	}
 
 }
