@@ -32,7 +32,7 @@ public class PuzzleLines : Game
 	}
 
 	public override string Question {
-		get {return Catalog.GetString ("How many lines do you count of in the figures below?");} 
+		get {return Catalog.GetString ("How many lines do you count of in the figures below? Consider a line a segment between two points with no crossing lines.");} 
 	}
 
 	public override string Answer {
@@ -43,6 +43,10 @@ public class PuzzleLines : Game
 		}
 	}
 
+	public override string Tip {
+		get { return Catalog.GetString ("It is an easy exercise if you systematically count the lines.");}
+	}
+
 	public override void Initialize ()
 	{
 		if (CurrentDifficulty==Difficulty.Easy)
