@@ -39,7 +39,7 @@ public class PuzzleOstracism : Game
 	}
 
 	public override string Question {
-		get {return Catalog.GetString ("Which equation does not belong to the group (A, B, C, D or E)?");} 
+		get {return Catalog.GetString ("Which equation does not belong to the group? Answer A, B, C, D or E.");} 
 	}
 
 
@@ -63,7 +63,7 @@ public class PuzzleOstracism : Game
 
 		for (int i = 0; i < random_indices.Count; i++)
 		{
-			if ((int) random_indices[i] == wrong_answer) {
+			if (random_indices[i] == wrong_answer) {
 				right_answer += ((char) (65 + i));
 				break;
 			}
@@ -77,12 +77,12 @@ public class PuzzleOstracism : Game
 		gr.Scale (area_width, area_height);
 		DrawBackground (gr);
 		PrepareGC (gr);
-		SetLargeFont (gr);
+		gr.SetLargeFont ();
 		
 		for (int i = 0; i < random_indices.Count; i++)
 		{
 			gr.MoveTo (x, y);
-			gr.ShowText (((char)( 65 + i)) + ") " +  equations [(int)random_indices[i]]);
+			gr.ShowText (((char)( 65 + i)) + ") " +  equations [random_indices[i]]);
 			y += 0.1;
 		}
 	}
